# -*- coding: utf-8 -*-

# Copyright (C) 2016-2020 RhodeCode GmbH
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License, version 3
# (only), as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# This program is dual-licensed. If you wish to learn more about the
# RhodeCode Enterprise Edition, including its added features, Support services,
# and proprietary license terms, please see https://rhodecode.com/licenses/

import logging

from . import config_keys
from .events import SshKeyFileChangeEvent
from .subscribers import generate_ssh_authorized_keys_file_subscriber

from rhodecode.config.settings_maker import SettingsMaker

log = logging.getLogger(__name__)


def _sanitize_settings_and_apply_defaults(settings):
    """
    Set defaults, convert to python types and validate settings.
    """
    settings_maker = SettingsMaker(settings)

    settings_maker.make_setting(config_keys.generate_authorized_keyfile, False, parser='bool')
    settings_maker.make_setting(config_keys.wrapper_allow_shell, False, parser='bool')
    settings_maker.make_setting(config_keys.enable_debug_logging, False, parser='bool')
    settings_maker.make_setting(config_keys.ssh_key_generator_enabled, True, parser='bool')

    settings_maker.make_setting(config_keys.authorized_keys_file_path, '~/.ssh/authorized_keys_rhodecode')
    settings_maker.make_setting(config_keys.wrapper_cmd, '')
    settings_maker.make_setting(config_keys.authorized_keys_line_ssh_opts, '')

    settings_maker.make_setting(config_keys.ssh_hg_bin, '~/.rccontrol/vcsserver-1/profile/bin/hg')
    settings_maker.make_setting(config_keys.ssh_git_bin, '~/.rccontrol/vcsserver-1/profile/bin/git')
    settings_maker.make_setting(config_keys.ssh_svn_bin, '~/.rccontrol/vcsserver-1/profile/bin/svnserve')

    settings_maker.env_expand()


def includeme(config):
    settings = config.registry.settings
    _sanitize_settings_and_apply_defaults(settings)

    # if we have enable generation of file, subscribe to event
    if settings[config_keys.generate_authorized_keyfile]:
        config.add_subscriber(
            generate_ssh_authorized_keys_file_subscriber, SshKeyFileChangeEvent)
